/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_uRIQ6BiJ);
  numBytes += sLine_init(&sLine_KJr5mLqm);
  numBytes += sLine_init(&sLine_ZAe9gN93);
  numBytes += sLine_init(&sLine_qlKpkjPk);
  numBytes += sLine_init(&sLine_WerIpBNi);
  numBytes += sBiquad_init(&sBiquad_s_DXm5pEh1);
  numBytes += sLine_init(&sLine_0G9uSx9n);
  numBytes += sLine_init(&sLine_zoSJCt5c);
  numBytes += sLine_init(&sLine_VnJSQiff);
  numBytes += sLine_init(&sLine_GhQ6dhbd);
  numBytes += sBiquad_init(&sBiquad_s_530UhoIv);
  numBytes += sLine_init(&sLine_umM8HwKO);
  numBytes += sLine_init(&sLine_VLwlpa9C);
  numBytes += sLine_init(&sLine_9ngsUJGH);
  numBytes += sLine_init(&sLine_x6k2zgrr);
  numBytes += sLine_init(&sLine_WLi1JgzX);
  numBytes += sBiquad_init(&sBiquad_s_T3qnFKbY);
  numBytes += sLine_init(&sLine_wl6NAanL);
  numBytes += sLine_init(&sLine_t7hmf8nz);
  numBytes += sLine_init(&sLine_d8QCS00O);
  numBytes += sLine_init(&sLine_bZe1xwts);
  numBytes += sLine_init(&sLine_BuWfxXmM);
  numBytes += sBiquad_init(&sBiquad_s_EKH99653);
  numBytes += sLine_init(&sLine_99Fa0uzR);
  numBytes += sLine_init(&sLine_JhufN57T);
  numBytes += sLine_init(&sLine_TmYg2HiC);
  numBytes += sLine_init(&sLine_Fv8yZ5fR);
  numBytes += sBiquad_init(&sBiquad_s_Qbbc4TAB);
  numBytes += sLine_init(&sLine_WhWUZgV5);
  numBytes += sLine_init(&sLine_iuBgOLlq);
  numBytes += sLine_init(&sLine_ZEbKIH59);
  numBytes += sLine_init(&sLine_VMkof5Xc);
  numBytes += sLine_init(&sLine_KByNcpG1);
  numBytes += sBiquad_init(&sBiquad_s_G0CTowkO);
  numBytes += sLine_init(&sLine_qQs5IpK7);
  numBytes += sPhasor_k_init(&sPhasor_Z4e3D788, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_ZQokkPCy);
  numBytes += sRPole_init(&sRPole_vqMBaN84);
  numBytes += sRPole_init(&sRPole_oRabG9Jk);
  numBytes += sTabhead_init(&sTabhead_iNhFojnw, &hTable_khED8MJr);
  numBytes += sTabread_init(&sTabread_Zn0depzd, &hTable_khED8MJr, false);
  numBytes += sTabread_init(&sTabread_2xmSc2OT, &hTable_khED8MJr, false);
  numBytes += sLine_init(&sLine_mI4Nc58Q);
  numBytes += sTabhead_init(&sTabhead_Q9x8dDLi, &hTable_C8kCittK);
  numBytes += sTabread_init(&sTabread_Xh7xOJFH, &hTable_C8kCittK, false);
  numBytes += sTabread_init(&sTabread_CPgPRqyb, &hTable_C8kCittK, false);
  numBytes += sLine_init(&sLine_sCrIV8Br);
  numBytes += sTabwrite_init(&sTabwrite_6ddkhNKi, &hTable_C8kCittK);
  numBytes += sTabwrite_init(&sTabwrite_qCXwFK6a, &hTable_khED8MJr);
  numBytes += sLine_init(&sLine_vabtI1Tl);
  numBytes += sPhasor_k_init(&sPhasor_lYbCV9IN, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_bJi9cLtr);
  numBytes += sRPole_init(&sRPole_A2IehJYW);
  numBytes += sRPole_init(&sRPole_gc23JTjt);
  numBytes += sTabhead_init(&sTabhead_w7ViaHRa, &hTable_ZpHdSDWr);
  numBytes += sTabread_init(&sTabread_IA8eTf3p, &hTable_ZpHdSDWr, false);
  numBytes += sTabread_init(&sTabread_8siVEKkj, &hTable_ZpHdSDWr, false);
  numBytes += sLine_init(&sLine_yov4eQZX);
  numBytes += sTabhead_init(&sTabhead_XBHu9jkS, &hTable_NjSNqTNT);
  numBytes += sTabread_init(&sTabread_7cWFUCUU, &hTable_NjSNqTNT, false);
  numBytes += sTabread_init(&sTabread_6DV6cD51, &hTable_NjSNqTNT, false);
  numBytes += sLine_init(&sLine_78MEMfpl);
  numBytes += sTabwrite_init(&sTabwrite_ocz1EK2Y, &hTable_NjSNqTNT);
  numBytes += sTabwrite_init(&sTabwrite_W4T6nldM, &hTable_ZpHdSDWr);
  numBytes += sLine_init(&sLine_REuKhhAj);
  numBytes += sPhasor_k_init(&sPhasor_OGWaKAiR, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_5MvTnuy9);
  numBytes += sRPole_init(&sRPole_TQvm6FOv);
  numBytes += sRPole_init(&sRPole_aEk43ajC);
  numBytes += sTabhead_init(&sTabhead_TMZvkCkL, &hTable_c0RaC2FK);
  numBytes += sTabread_init(&sTabread_3JHSRTUj, &hTable_c0RaC2FK, false);
  numBytes += sTabread_init(&sTabread_NfBsefEr, &hTable_c0RaC2FK, false);
  numBytes += sLine_init(&sLine_z3pdwBDT);
  numBytes += sTabhead_init(&sTabhead_ZsNEVVov, &hTable_Rjs9xVEQ);
  numBytes += sTabread_init(&sTabread_9XI0cy1e, &hTable_Rjs9xVEQ, false);
  numBytes += sTabread_init(&sTabread_kV4C2Slv, &hTable_Rjs9xVEQ, false);
  numBytes += sLine_init(&sLine_uONvVTHG);
  numBytes += sTabwrite_init(&sTabwrite_1sVRzSfE, &hTable_Rjs9xVEQ);
  numBytes += sTabwrite_init(&sTabwrite_2iS43VKo, &hTable_c0RaC2FK);
  numBytes += cVar_init_f(&cVar_XzaQTmVg, 0.0f);
  numBytes += cVar_init_f(&cVar_zFPnH1Bx, 0.0f);
  numBytes += cVar_init_f(&cVar_Htn3ynaP, 0.0f);
  numBytes += cVar_init_f(&cVar_PxvTWe99, 0.0f);
  numBytes += cSlice_init(&cSlice_dAo9ewqK, 1, -1);
  numBytes += cVar_init_f(&cVar_lCEBfqy7, 1337.0f);
  numBytes += cVar_init_f(&cVar_430xMTWr, 0.0f);
  numBytes += cIf_init(&cIf_8BxcpWoV, false);
  numBytes += cIf_init(&cIf_ebeEqnkh, false);
  numBytes += cBinop_init(&cBinop_IPMX2qOm, 0.0f); // __pow
  numBytes += cIf_init(&cIf_T996rl48, false);
  numBytes += cBinop_init(&cBinop_CUR5iDf7, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_uI5ZqSBb, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_DCABaKK8, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_jrXdprV8, 0.0f);
  numBytes += cIf_init(&cIf_jcc6ImxF, false);
  numBytes += cIf_init(&cIf_5wOMAdcz, false);
  numBytes += cBinop_init(&cBinop_dELV8zOs, 0.0f); // __pow
  numBytes += cIf_init(&cIf_lmoHRTZX, false);
  numBytes += cBinop_init(&cBinop_jyPCk1gx, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_HmrScfdk, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_2uJEk6As, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_PabYq5z1, 0.0f);
  numBytes += cIf_init(&cIf_NHbr0sj4, false);
  numBytes += cIf_init(&cIf_1MsUUMih, false);
  numBytes += cBinop_init(&cBinop_5DLUFM1s, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Y1Z66s47, false);
  numBytes += cBinop_init(&cBinop_8mbOlQrV, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_0SOAoCmC, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_8LOymRmQ, -15.0f); // __eq
  numBytes += cIf_init(&cIf_osRWHJqW, false);
  numBytes += cSlice_init(&cSlice_CN94E8Pv, 1, -1);
  numBytes += cVar_init_f(&cVar_sR6ilbon, 0.0f);
  numBytes += cSlice_init(&cSlice_hPd37HpI, 1, -1);
  numBytes += cVar_init_f(&cVar_HnLJNKTn, 0.0f);
  numBytes += cSlice_init(&cSlice_laTIDrlz, 1, -1);
  numBytes += cVar_init_f(&cVar_qItP0mSV, 0.0f);
  numBytes += cSlice_init(&cSlice_yAVHQsxj, 1, -1);
  numBytes += cVar_init_f(&cVar_IJmjElto, 0.313f);
  numBytes += cBinop_init(&cBinop_tuabwnqE, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_AUELyGrQ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_AtYwHV1A, 0.0f);
  numBytes += cVar_init_f(&cVar_VzkCVeMS, 1337.0f);
  numBytes += cVar_init_f(&cVar_c8Uvg8go, 0.3f);
  numBytes += cBinop_init(&cBinop_NldFY438, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9plnJPmd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kKXUd3R5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_w0nTJ3jr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YmGKp9lD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BQljdXr7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_R8SX3xsV, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_xyXPF84w, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ZUNVaPmb, 0.0f);
  numBytes += cVar_init_f(&cVar_kVqVABTS, 1337.0f);
  numBytes += cVar_init_f(&cVar_xlws5u44, 0.313f);
  numBytes += cBinop_init(&cBinop_1FhQEWpV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2qpSPPBw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_d25MxAnJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8vF4kwAv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PThGaD8i, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_m6wZpuHa, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_nZ5qyzJm, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Q8MyCwQJ, 0.0f);
  numBytes += cVar_init_f(&cVar_AjgpHURx, 1037.0f);
  numBytes += cVar_init_f(&cVar_kzYhzWDR, 0.4f);
  numBytes += cBinop_init(&cBinop_5zuuh3xr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9kaiPdZK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_x9l42mcV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eKxvmLgp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6tzAyDcu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kpr85cwB, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_oxg4fbbi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_C8hberev, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YmHgqUKt, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_fhYc3OLo, 1, -1);
  numBytes += cVar_init_f(&cVar_AkJqcOpG, 1337.0f);
  numBytes += cVar_init_f(&cVar_CdJFpjVv, 0.0f);
  numBytes += cIf_init(&cIf_sbVn9KMI, false);
  numBytes += cIf_init(&cIf_yS5RBvVw, false);
  numBytes += cBinop_init(&cBinop_NpZSOkPu, 0.0f); // __pow
  numBytes += cIf_init(&cIf_FTX5BwVq, false);
  numBytes += cBinop_init(&cBinop_DEs6jFCt, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_g49e8CXU, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_5vXnMMFU, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_9fg98XsS, 0.0f);
  numBytes += cIf_init(&cIf_cRgg51Q7, false);
  numBytes += cIf_init(&cIf_8zN9hEAB, false);
  numBytes += cBinop_init(&cBinop_8ZtPqzU1, 0.0f); // __pow
  numBytes += cIf_init(&cIf_DtUaYOQJ, false);
  numBytes += cBinop_init(&cBinop_6NmY9Awy, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_90j0sO8b, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_vMAFpfeq, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_PSy4ZjN2, 0.0f);
  numBytes += cIf_init(&cIf_Xe1rZl3n, false);
  numBytes += cIf_init(&cIf_bR9yTzOp, false);
  numBytes += cBinop_init(&cBinop_JgVi75IU, 0.0f); // __pow
  numBytes += cIf_init(&cIf_BwXECmSn, false);
  numBytes += cBinop_init(&cBinop_2Z63UDtl, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_fmo6QwAF, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_WCwyKQGS, -15.0f); // __eq
  numBytes += cIf_init(&cIf_g3MSfzMK, false);
  numBytes += cSlice_init(&cSlice_lOMvxdFV, 1, -1);
  numBytes += cVar_init_f(&cVar_07uGiGdZ, 0.0f);
  numBytes += cSlice_init(&cSlice_p70btcws, 1, -1);
  numBytes += cVar_init_f(&cVar_FcUa4G6Q, 0.0f);
  numBytes += cSlice_init(&cSlice_b3axF4mj, 1, -1);
  numBytes += cVar_init_f(&cVar_sWwq4Svx, 0.0f);
  numBytes += cSlice_init(&cSlice_jOCikP34, 1, -1);
  numBytes += cVar_init_f(&cVar_5u6iXPKr, 0.313f);
  numBytes += cBinop_init(&cBinop_BT7LHGot, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_sIILnuKR, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_DUWWoktu, 0.0f);
  numBytes += cVar_init_f(&cVar_yx8IaTZr, 1337.0f);
  numBytes += cVar_init_f(&cVar_8vb5uucG, 0.3f);
  numBytes += cBinop_init(&cBinop_AZmYeAfo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UuPeAPnD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IwBTOsIE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_O8AXn63D, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xADUGgE6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UR5kLfpL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1oWeJjef, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Pe1Wvv0l, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_gDf2zTic, 0.0f);
  numBytes += cVar_init_f(&cVar_38H3fZmM, 1337.0f);
  numBytes += cVar_init_f(&cVar_1FoDb7Vs, 0.313f);
  numBytes += cBinop_init(&cBinop_wNnRonbV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_x6wdgMTN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vwrWpjVm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zGu6dMTZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4O5N1ANy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KEMp9qUK, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_25TzX6pn, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_lbJnZ10G, 0.0f);
  numBytes += cVar_init_f(&cVar_yO68P4yd, 1037.0f);
  numBytes += cVar_init_f(&cVar_sggnTu43, 0.4f);
  numBytes += cBinop_init(&cBinop_DXWhmc5O, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7NzAfUpu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YmM9VfUZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_b52Wywww, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_w4qPknPe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jp0RJTyd, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_QEWmHoIb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uBN4WSmC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FMtH8KsD, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Fw8Fo8LY, 5705.6f);
  numBytes += cVar_init_f(&cVar_QK9HPWHL, 313.3f);
  numBytes += cBinop_init(&cBinop_ivUGIjlW, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_WGyrRjnz, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_8DnCSUmq, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_d8rkvGUY, 0.0f);
  numBytes += cVar_init_f(&cVar_tSFVD0RI, 0.0f);
  numBytes += cVar_init_f(&cVar_gsGErtDB, 0.0f);
  numBytes += cVar_init_f(&cVar_UCNTejzr, 0.0f);
  numBytes += cVar_init_f(&cVar_OQLlLDYU, 0.0f);
  numBytes += cVar_init_f(&cVar_aDWscPky, 0.0f);
  numBytes += cVar_init_f(&cVar_ERWOYUum, 0.0f);
  numBytes += cVar_init_f(&cVar_bhjeQmnl, 0.0f);
  numBytes += cVar_init_f(&cVar_SDJfNy7o, 0.0f);
  numBytes += cVar_init_f(&cVar_2mosq0lA, 0.0f);
  numBytes += cVar_init_f(&cVar_a9RSAfSx, 0.0f);
  numBytes += cVar_init_f(&cVar_htHpKDJi, 0.0f);
  numBytes += cVar_init_s(&cVar_kII3SEqi, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_v6T97sSV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EKUyDbvr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QzbsP73z, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_866y0rLw, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_ljrZxAHJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tY2fesmt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5gAyENIo, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_nNUxFM1U, 0.0f);
  numBytes += cDelay_init(this, &cDelay_v2NtUn1v, 0.0f);
  numBytes += hTable_init(&hTable_C8kCittK, 256);
  numBytes += cDelay_init(this, &cDelay_6gtsRis4, 0.0f);
  numBytes += cDelay_init(this, &cDelay_zQgZdZ8N, 0.0f);
  numBytes += hTable_init(&hTable_khED8MJr, 256);
  numBytes += cVar_init_f(&cVar_pvcGvtUB, 14.0f);
  numBytes += cBinop_init(&cBinop_Q3jqAMMN, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_pCJZsCfL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FL7tyaOZ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_cnLA9BwX, 14.0f);
  numBytes += cBinop_init(&cBinop_5hRKySDL, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_gIeuRhAR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fJQLmtB2, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_DtVbftSO, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_b3R8ZkGu, 1, -1);
  numBytes += cVar_init_f(&cVar_6c5thhST, 0.2f);
  numBytes += cSlice_init(&cSlice_4VD7l3Dj, 1, -1);
  numBytes += cVar_init_f(&cVar_GqAVtLzJ, 0.0f);
  numBytes += cSlice_init(&cSlice_DytDCjtf, 1, -1);
  numBytes += cVar_init_f(&cVar_nbj0MVZM, 2.0f);
  numBytes += cSlice_init(&cSlice_caK1y9jo, 1, -1);
  numBytes += cVar_init_f(&cVar_V7Ne2TXF, 0.5f);
  numBytes += cVar_init_s(&cVar_jHQZFu3d, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_vx5biWG8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FxQqw34d, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xUC7ZuNs, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_NkoH3YKP, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_IYsELmhF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vyHDjAJT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WSjbjGf1, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_IGgfMmJi, 0.0f);
  numBytes += cDelay_init(this, &cDelay_zgZ4GyiL, 0.0f);
  numBytes += hTable_init(&hTable_NjSNqTNT, 256);
  numBytes += cDelay_init(this, &cDelay_tUmgcNNU, 0.0f);
  numBytes += cDelay_init(this, &cDelay_4TiZVvkt, 0.0f);
  numBytes += hTable_init(&hTable_ZpHdSDWr, 256);
  numBytes += cVar_init_f(&cVar_Yx6KxmDZ, 14.0f);
  numBytes += cBinop_init(&cBinop_2yTHPsDT, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_3y8zeeFF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QcjyW8sX, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_dLwLzVT5, 14.0f);
  numBytes += cBinop_init(&cBinop_qyM5T2ni, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_4Fg5KgOT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TUWfJ5do, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_YtRxZLQC, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_uReuzCqY, 1, -1);
  numBytes += cVar_init_f(&cVar_lPXMU2Kn, 0.2f);
  numBytes += cSlice_init(&cSlice_K4fCmMVQ, 1, -1);
  numBytes += cVar_init_f(&cVar_52Mv8V6j, 0.0f);
  numBytes += cSlice_init(&cSlice_KL6UeIpx, 1, -1);
  numBytes += cVar_init_f(&cVar_lSYmohsC, 2.0f);
  numBytes += cSlice_init(&cSlice_t5FRDCdu, 1, -1);
  numBytes += cVar_init_f(&cVar_kkAvBEF6, 0.5f);
  numBytes += cVar_init_s(&cVar_wZNCwqpn, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_aOZDODzI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UIa9J7JB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_k1vrykDG, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_cRDVCZHT, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_A2Fjr5pw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CEArNN8P, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_v1Pgv8zQ, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_DoRP9RUc, 0.0f);
  numBytes += cDelay_init(this, &cDelay_wQ35vTCU, 0.0f);
  numBytes += hTable_init(&hTable_Rjs9xVEQ, 256);
  numBytes += cDelay_init(this, &cDelay_p5WuNYfL, 0.0f);
  numBytes += cDelay_init(this, &cDelay_JWYTGtWG, 0.0f);
  numBytes += hTable_init(&hTable_c0RaC2FK, 256);
  numBytes += cVar_init_f(&cVar_P4nZo3zF, 14.0f);
  numBytes += cBinop_init(&cBinop_UIvrNqDc, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_3M5XRdwo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pZsZScRd, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_B48xwbUx, 14.0f);
  numBytes += cBinop_init(&cBinop_FQ4LNV6F, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_wihsT90Y, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_s7TqJwTl, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_JjzGsSYX, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_xqFlHdOM, 1, -1);
  numBytes += cVar_init_f(&cVar_zCRStbNf, 0.2f);
  numBytes += cSlice_init(&cSlice_dVNPQfre, 1, -1);
  numBytes += cVar_init_f(&cVar_j3AtuhWq, 0.0f);
  numBytes += cSlice_init(&cSlice_pUwqjxQ7, 1, -1);
  numBytes += cVar_init_f(&cVar_j3iZ6a7d, 2.0f);
  numBytes += cSlice_init(&cSlice_Hrw3y7i4, 1, -1);
  numBytes += cVar_init_f(&cVar_xrkQ97I6, 0.5f);
  numBytes += sVarf_init(&sVarf_f692pRpR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_x2MSCobF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_W4PVvOX9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fmMpsCOG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HxiJJjYB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uATW42o9, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_C8kCittK);
  hTable_free(&hTable_khED8MJr);
  hTable_free(&hTable_NjSNqTNT);
  hTable_free(&hTable_ZpHdSDWr);
  hTable_free(&hTable_Rjs9xVEQ);
  hTable_free(&hTable_c0RaC2FK);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_C8kCittK; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_khED8MJr; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_NjSNqTNT; // del-1397-flanger-r
    case 0x578173CB: return &hTable_ZpHdSDWr; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_Rjs9xVEQ; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_c0RaC2FK; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VViIrxPI_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tNIhZJJI_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aXu7RZjp_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wk2ApgyV_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zdWppVZU_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_B112oPvJ_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_a40So1I4_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_M3cfvUdi_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YYH6zbQD_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sxUqu0FI_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aBegCth4_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QbBnyW5U_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qCdfeWYA_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IhDDhcGl_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qu9SnytS_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_usoIqnmC_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nKW1Rqm8_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_X4ADXnuz_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NWfW1UmR_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p2dhTpqn_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wgXgN0rM_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mjPaqdQ6_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UxffUNM2_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dH5wkyX2_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dqyCl9nA_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WO6zUK5f_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1YhXy4Fk_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PApR4C9t_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1SENCUDB_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5NI9PjUj_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vYb67GtK_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9uCzKMgo_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XV39LpEH_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jp1EcPZO_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lUebIi1X_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_646ttw9J_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BjoU7pJr_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6XoHl93b_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4WYNL8Pw_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fP9EwrOL_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XFujlyht_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c8UeJwBv_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_73Y7URcs_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HTC7zDiD_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JbVasEvL_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kXRJ6daa_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JfyRyJU7_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZqQbFv3u_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gnjvJDqY_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YL03UqPq_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Rb2s26pO_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vuFNOonz_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DC24oYFS_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QetMiaZf_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F9D5RrrA_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3BKKqEk2_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_C5GS5nig_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_XzaQTmVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6UnuBLrn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_zFPnH1Bx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mR9ZddFs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Htn3ynaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MWNJX415_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_PxvTWe99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X6afB3m4_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H4v9PUn2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sjmjt5RR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l6IAIh5C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Uw4VJR94_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dAo9ewqK, 0, m, &cSlice_dAo9ewqK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lW39wqoS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_dAo9ewqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DYTLeCfc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DYTLeCfc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_lCEBfqy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DYTLeCfc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_DYTLeCfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NWfW1UmR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_430xMTWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_euQlEi0X_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_8BxcpWoV, 0, m, &cIf_8BxcpWoV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_8BxcpWoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0Wg7G8P5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_ebeEqnkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_FaPEGMq6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_RTQw8Qho_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_KcHbuDxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IPMX2qOm, HV_BINOP_POW, 0, m, &cBinop_IPMX2qOm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IPMX2qOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T996rl48, 0, m, &cIf_T996rl48_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GbQiPiS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Gtx1nkHd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Ece8qLVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ebeEqnkh, 0, m, &cIf_ebeEqnkh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4hT1pKbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TFfOwjrE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TFfOwjrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ebeEqnkh, 1, m, &cIf_ebeEqnkh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RTQw8Qho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_GbQiPiS4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FaPEGMq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_T996rl48, 0, m, &cIf_T996rl48_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Gtx1nkHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IPMX2qOm, HV_BINOP_POW, 1, m, &cBinop_IPMX2qOm_sendMessage);
  cMsg_KcHbuDxa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_T996rl48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_oxg4fbbi, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_euQlEi0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8BxcpWoV, 1, m, &cIf_8BxcpWoV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0Wg7G8P5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uI5ZqSBb, HV_BINOP_GREATER_THAN, 1, m, &cBinop_uI5ZqSBb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DCABaKK8, HV_BINOP_EQ, 1, m, &cBinop_DCABaKK8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZzGRrLyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CUR5iDf7, HV_BINOP_ADD, 0, m, &cBinop_CUR5iDf7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CUR5iDf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4hT1pKbU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ece8qLVV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uI5ZqSBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T996rl48, 1, m, &cIf_T996rl48_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DCABaKK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gIZkANvD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_gIZkANvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_oxg4fbbi, m);
}

void Heavy_WSTD_FL3NGR::cCast_VJ5yYQln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CUR5iDf7, HV_BINOP_ADD, 1, m, &cBinop_CUR5iDf7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uI5ZqSBb, HV_BINOP_GREATER_THAN, 0, m, &cBinop_uI5ZqSBb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DCABaKK8, HV_BINOP_EQ, 0, m, &cBinop_DCABaKK8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_b9ZNfeqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_430xMTWr, 0, m, &cVar_430xMTWr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YZdlBUQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZzGRrLyh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_jrXdprV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0EwZ1Tqt_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_jcc6ImxF, 0, m, &cIf_jcc6ImxF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_jcc6ImxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VYMifjRh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_5wOMAdcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_5OlQ93VZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_gIq4HFX7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_jWU708KC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dELV8zOs, HV_BINOP_POW, 0, m, &cBinop_dELV8zOs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dELV8zOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lmoHRTZX, 0, m, &cIf_lmoHRTZX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TQtGdL0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_yntozIzL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cHS7S6AZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5wOMAdcz, 0, m, &cIf_5wOMAdcz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_C7KZmZZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SPUpOlPi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SPUpOlPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5wOMAdcz, 1, m, &cIf_5wOMAdcz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gIq4HFX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_TQtGdL0s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5OlQ93VZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_lmoHRTZX, 0, m, &cIf_lmoHRTZX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yntozIzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dELV8zOs, HV_BINOP_POW, 1, m, &cBinop_dELV8zOs_sendMessage);
  cMsg_jWU708KC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_lmoHRTZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wHbKLlmw_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZDdxsZF1_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_BOZEqEcB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_0EwZ1Tqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jcc6ImxF, 1, m, &cIf_jcc6ImxF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VYMifjRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HmrScfdk, HV_BINOP_GREATER_THAN, 1, m, &cBinop_HmrScfdk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2uJEk6As, HV_BINOP_EQ, 1, m, &cBinop_2uJEk6As_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Xt3BSjAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jyPCk1gx, HV_BINOP_ADD, 0, m, &cBinop_jyPCk1gx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jyPCk1gx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C7KZmZZI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cHS7S6AZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HmrScfdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lmoHRTZX, 1, m, &cIf_lmoHRTZX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2uJEk6As_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wFYuxIWb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_wFYuxIWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wHbKLlmw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZDdxsZF1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_BOZEqEcB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_H9NHxlZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xt3BSjAb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_upYOEWVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jyPCk1gx, HV_BINOP_ADD, 1, m, &cBinop_jyPCk1gx_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HmrScfdk, HV_BINOP_GREATER_THAN, 0, m, &cBinop_HmrScfdk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2uJEk6As, HV_BINOP_EQ, 0, m, &cBinop_2uJEk6As_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gQGa5OvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jrXdprV8, 0, m, &cVar_jrXdprV8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_PabYq5z1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_u7EFWbEa_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_NHbr0sj4, 0, m, &cIf_NHbr0sj4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_NHbr0sj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_i0hc3Tdy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_1MsUUMih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_1tHKAona_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_0WqgBQTm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_lmnurouV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5DLUFM1s, HV_BINOP_POW, 0, m, &cBinop_5DLUFM1s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5DLUFM1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y1Z66s47, 0, m, &cIf_Y1Z66s47_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iGzHbsBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_pmZf18v7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2LBkM9JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1MsUUMih, 0, m, &cIf_1MsUUMih_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JWPPkD7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XdnLUXpK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XdnLUXpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1MsUUMih, 1, m, &cIf_1MsUUMih_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0WqgBQTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_iGzHbsBm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1tHKAona_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Y1Z66s47, 0, m, &cIf_Y1Z66s47_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pmZf18v7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5DLUFM1s, HV_BINOP_POW, 1, m, &cBinop_5DLUFM1s_sendMessage);
  cMsg_lmnurouV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_Y1Z66s47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_YmHgqUKt, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_u7EFWbEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NHbr0sj4, 1, m, &cIf_NHbr0sj4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_i0hc3Tdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0SOAoCmC, HV_BINOP_GREATER_THAN, 1, m, &cBinop_0SOAoCmC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8LOymRmQ, HV_BINOP_EQ, 1, m, &cBinop_8LOymRmQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Z5hWTFef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8mbOlQrV, HV_BINOP_ADD, 0, m, &cBinop_8mbOlQrV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8mbOlQrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JWPPkD7M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2LBkM9JM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0SOAoCmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y1Z66s47, 1, m, &cIf_Y1Z66s47_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8LOymRmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_klEYnNF5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_klEYnNF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YmHgqUKt, m);
}

void Heavy_WSTD_FL3NGR::cCast_UrPdml2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8mbOlQrV, HV_BINOP_ADD, 1, m, &cBinop_8mbOlQrV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0SOAoCmC, HV_BINOP_GREATER_THAN, 0, m, &cBinop_0SOAoCmC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8LOymRmQ, HV_BINOP_EQ, 0, m, &cBinop_8LOymRmQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_szV1RtAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PabYq5z1, 0, m, &cVar_PabYq5z1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YMJKkOWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z5hWTFef_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_osRWHJqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_C8hberev, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_p1vIKh6m_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CN94E8Pv, 0, m, &cSlice_CN94E8Pv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7wUaSyqc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_CN94E8Pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OTsLzf1r_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OTsLzf1r_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_sR6ilbon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OTsLzf1r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_OTsLzf1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nKW1Rqm8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_7wUaSyqc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hPd37HpI, 0, m, &cSlice_hPd37HpI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Uw4VJR94_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_hPd37HpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0zvFyIHp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0zvFyIHp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_HnLJNKTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0zvFyIHp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_0zvFyIHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wgXgN0rM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_lW39wqoS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_laTIDrlz, 0, m, &cSlice_laTIDrlz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dfiVdwR4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_laTIDrlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Azf1XvAz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Azf1XvAz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_qItP0mSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Azf1XvAz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Azf1XvAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_X4ADXnuz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_dfiVdwR4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yAVHQsxj, 0, m, &cSlice_yAVHQsxj_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_yAVHQsxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pxgjz9c3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pxgjz9c3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_IJmjElto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pxgjz9c3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_pxgjz9c3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_p2dhTpqn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_pVyAtBPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uRIQ6BiJ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_5qQbdlQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KJr5mLqm, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6XhCA8Mc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZAe9gN93, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_T2N6k84Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qlKpkjPk, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_eDnDReBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WerIpBNi, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_uCaVvGp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9DLjucwR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_9DLjucwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tuabwnqE, HV_BINOP_DIVIDE, 1, m, &cBinop_tuabwnqE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_riCfjJAw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_1HWkBGFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_nTpokybi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vOdDFpmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_1HWkBGFZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nTpokybi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tuabwnqE, HV_BINOP_DIVIDE, 0, m, &cBinop_tuabwnqE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_riCfjJAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vOdDFpmw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_tuabwnqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AUELyGrQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_AUELyGrQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AUELyGrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zltSceFj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_04TiLAL7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_cwLBNXDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wrGg3ls7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_V1PlBbYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RB4vD1FA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ZbVtJfKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_gzm6MTYv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gzm6MTYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AUELyGrQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_AUELyGrQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CWaddL1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_YC7MKCrb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YC7MKCrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tR7rsE2M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ZFvdHt8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AtYwHV1A, 1, m, &cVar_AtYwHV1A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_AtYwHV1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BBDCcwac_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9QwTUatZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9plnJPmd, HV_BINOP_MULTIPLY, 1, m, &cBinop_9plnJPmd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jAgfarwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9QwTUatZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_y2qUoGGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_tDttaUy4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tDttaUy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kKXUd3R5, HV_BINOP_MULTIPLY, 1, m, &cBinop_kKXUd3R5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KKu7iPtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w0nTJ3jr, HV_BINOP_MULTIPLY, 1, m, &cBinop_w0nTJ3jr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HByeeHcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KKu7iPtK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dkLZDnyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YmGKp9lD, HV_BINOP_MULTIPLY, 1, m, &cBinop_YmGKp9lD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EQozxfq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vtnO2t6C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vtnO2t6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BQljdXr7, HV_BINOP_MULTIPLY, 1, m, &cBinop_BQljdXr7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_VzkCVeMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ucqIl85M_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ZbVtJfKV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MkiTIlm1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_c8Uvg8go_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_CWaddL1G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zltSceFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_cwLBNXDV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_04TiLAL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_V1PlBbYP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_wrGg3ls7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dH5wkyX2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_RB4vD1FA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UxffUNM2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_1yJPmMRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mjPaqdQ6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_tR7rsE2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AsmLlW7u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AsmLlW7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NldFY438, HV_BINOP_MULTIPLY, 1, m, &cBinop_NldFY438_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NldFY438_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uzlrL8xD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uzlrL8xD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1yJPmMRK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_BBDCcwac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_BH4f1J0j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BH4f1J0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9zwq6TNt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9FTOyek3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mRDQgs14_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jFURktjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lEqdVvJJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qw1n5Ef3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9plnJPmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pVyAtBPB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_kKXUd3R5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5qQbdlQn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_w0nTJ3jr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6XhCA8Mc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YmGKp9lD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T2N6k84Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BQljdXr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eDnDReBK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_t9QPczkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VzkCVeMS, 0, m, &cVar_VzkCVeMS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sz2EgS69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c8Uvg8go, 1, m, &cVar_c8Uvg8go_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lEqdVvJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kKXUd3R5, HV_BINOP_MULTIPLY, 0, m, &cBinop_kKXUd3R5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9FTOyek3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BQljdXr7, HV_BINOP_MULTIPLY, 0, m, &cBinop_BQljdXr7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jFURktjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w0nTJ3jr, HV_BINOP_MULTIPLY, 0, m, &cBinop_w0nTJ3jr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9zwq6TNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_Qw1n5Ef3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9plnJPmd, HV_BINOP_MULTIPLY, 0, m, &cBinop_9plnJPmd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mRDQgs14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YmGKp9lD, HV_BINOP_MULTIPLY, 0, m, &cBinop_YmGKp9lD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ucqIl85M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c8Uvg8go, 0, m, &cVar_c8Uvg8go_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MkiTIlm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AtYwHV1A, 0, m, &cVar_AtYwHV1A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6cDt1YRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0G9uSx9n, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_IZazIIVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zoSJCt5c, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_VrfF1tGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VnJSQiff, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_KsxLdTIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GhQ6dhbd, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Ed7ZY3oz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_y6WBCeKK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_y6WBCeKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R8SX3xsV, HV_BINOP_DIVIDE, 1, m, &cBinop_R8SX3xsV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ulp8edqT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_sNc2GRLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_wZ5T4wed_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_VCAuF8oP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_sNc2GRLl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wZ5T4wed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R8SX3xsV, HV_BINOP_DIVIDE, 0, m, &cBinop_R8SX3xsV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Ulp8edqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VCAuF8oP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_R8SX3xsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xyXPF84w, HV_BINOP_MULTIPLY, 1, m, &cBinop_xyXPF84w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xyXPF84w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kOrhSXZ6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cbjiq68M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_GvKUtYwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oGnz3fAJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_Ivs6wbeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7iu7aW1Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wasKRLzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Eu8QdV3k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Eu8QdV3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xyXPF84w, HV_BINOP_MULTIPLY, 0, m, &cBinop_xyXPF84w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pbMGuXqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_YFAWbzsB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YFAWbzsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iXgsPEhb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NpEYzvfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d25MxAnJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_d25MxAnJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lXjNeo2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZUNVaPmb, 1, m, &cVar_ZUNVaPmb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_D5IDo3H2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8vF4kwAv, HV_BINOP_MULTIPLY, 1, m, &cBinop_8vF4kwAv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_gooWCvwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tRHIFc82_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tRHIFc82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PThGaD8i, HV_BINOP_MULTIPLY, 1, m, &cBinop_PThGaD8i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_ZUNVaPmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kFbATS9f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_kVqVABTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y7rqviYW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_wasKRLzD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H80ePvUN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_xlws5u44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_pbMGuXqj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kOrhSXZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_GvKUtYwt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Cbjiq68M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Ivs6wbeu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_oGnz3fAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1YhXy4Fk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_7iu7aW1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WO6zUK5f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_8WU0lvpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dqyCl9nA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_iXgsPEhb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6WwFBLq8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6WwFBLq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1FhQEWpV, HV_BINOP_MULTIPLY, 1, m, &cBinop_1FhQEWpV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1FhQEWpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8GaDwNhJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8GaDwNhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8WU0lvpg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_kFbATS9f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XOWsRVRx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XOWsRVRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pfDRhw46_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y7R70nW9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gGD3lQBa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J5WWDXGJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2qpSPPBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6cDt1YRx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_d25MxAnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IZazIIVf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_8vF4kwAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VrfF1tGd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_PThGaD8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KsxLdTIP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_QQjvK1Zt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xlws5u44, 1, m, &cVar_xlws5u44_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GVapInoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kVqVABTS, 0, m, &cVar_kVqVABTS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_H80ePvUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZUNVaPmb, 0, m, &cVar_ZUNVaPmb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Y7rqviYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xlws5u44, 0, m, &cVar_xlws5u44_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gGD3lQBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d25MxAnJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_d25MxAnJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_y7R70nW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8vF4kwAv, HV_BINOP_MULTIPLY, 0, m, &cBinop_8vF4kwAv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_J5WWDXGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2qpSPPBw, HV_BINOP_MULTIPLY, 0, m, &cBinop_2qpSPPBw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pfDRhw46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PThGaD8i, HV_BINOP_MULTIPLY, 0, m, &cBinop_PThGaD8i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xFPKEMZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_umM8HwKO, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_0zT9yjva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VLwlpa9C, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_kYSfyIfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9ngsUJGH, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_5RecDiAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x6k2zgrr, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_X6hq4tWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WLi1JgzX, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_vzVG2Sso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_n7hntNcY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_n7hntNcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m6wZpuHa, HV_BINOP_DIVIDE, 1, m, &cBinop_m6wZpuHa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MM97snB2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_nA1vH0ZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_wfEJoQzi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_adL8iXEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_nA1vH0ZQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wfEJoQzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m6wZpuHa, HV_BINOP_DIVIDE, 0, m, &cBinop_m6wZpuHa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MM97snB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_adL8iXEv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_m6wZpuHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nZ5qyzJm, HV_BINOP_MULTIPLY, 1, m, &cBinop_nZ5qyzJm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nZ5qyzJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BKxTzcIG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yfVcoGRw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_yc0868rq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_N5hnKYU1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_SjtWzuif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1Txe4FKy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wjd4lWZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_nFdzzIlW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nFdzzIlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nZ5qyzJm, HV_BINOP_MULTIPLY, 0, m, &cBinop_nZ5qyzJm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RFrpRORG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ltZ8qHML_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ltZ8qHML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0DbDF3Qs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IrqplVoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9kaiPdZK, HV_BINOP_MULTIPLY, 1, m, &cBinop_9kaiPdZK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4zujdsKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UVH19pQb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UVH19pQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IrqplVoy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_LK10UBiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Gj53PRBf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Gj53PRBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x9l42mcV, HV_BINOP_MULTIPLY, 1, m, &cBinop_x9l42mcV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_i2P3nPKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eKxvmLgp, HV_BINOP_MULTIPLY, 1, m, &cBinop_eKxvmLgp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_j8pdQl8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UrCo8dvg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UrCo8dvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_i2P3nPKz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ldz46DrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q8MyCwQJ, 1, m, &cVar_Q8MyCwQJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5P6npJBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6tzAyDcu, HV_BINOP_MULTIPLY, 1, m, &cBinop_6tzAyDcu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_iN5QdppP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pR1mRGQ8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pR1mRGQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kpr85cwB, HV_BINOP_MULTIPLY, 1, m, &cBinop_kpr85cwB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Q8MyCwQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cW0PY67T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_AjgpHURx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1O4ZoOEW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_wjd4lWZ5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fhMCwOhU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_kzYhzWDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_RFrpRORG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yfVcoGRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_SjtWzuif_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BKxTzcIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_yc0868rq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_N5hnKYU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5NI9PjUj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_1Txe4FKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1SENCUDB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_lbMA3BUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PApR4C9t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_0DbDF3Qs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_HqNilW7O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HqNilW7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5zuuh3xr, HV_BINOP_MULTIPLY, 1, m, &cBinop_5zuuh3xr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5zuuh3xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6rCFCmbN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6rCFCmbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lbMA3BUn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_cW0PY67T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Fc4ukmNR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Fc4ukmNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_93DJ8nHy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oC7kT0xK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5mqaW3Z7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gDBB1m9K_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nKzGcaUy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XtTMaeTY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9kaiPdZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xFPKEMZd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_x9l42mcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0zT9yjva_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_eKxvmLgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kYSfyIfE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6tzAyDcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5RecDiAI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_kpr85cwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X6hq4tWq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_Qcd4ynPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kzYhzWDR, 1, m, &cVar_kzYhzWDR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KFiq1a1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AjgpHURx, 0, m, &cVar_AjgpHURx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_oC7kT0xK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kpr85cwB, HV_BINOP_MULTIPLY, 0, m, &cBinop_kpr85cwB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gDBB1m9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eKxvmLgp, HV_BINOP_MULTIPLY, 0, m, &cBinop_eKxvmLgp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_93DJ8nHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_XtTMaeTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9kaiPdZK, HV_BINOP_MULTIPLY, 0, m, &cBinop_9kaiPdZK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5mqaW3Z7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6tzAyDcu, HV_BINOP_MULTIPLY, 0, m, &cBinop_6tzAyDcu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nKzGcaUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x9l42mcV, HV_BINOP_MULTIPLY, 0, m, &cBinop_x9l42mcV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1O4ZoOEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kzYhzWDR, 0, m, &cVar_kzYhzWDR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fhMCwOhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q8MyCwQJ, 0, m, &cVar_Q8MyCwQJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wHbKLlmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_osRWHJqW, 1, m, &cIf_osRWHJqW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Bzrj25Id_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_C8hberev, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ZDdxsZF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bzrj25Id_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BOZEqEcB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_osRWHJqW, 0, m, &cIf_osRWHJqW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_zSahA7GU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fhYc3OLo, 0, m, &cSlice_fhYc3OLo_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lPxxqSXY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_fhYc3OLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Mno7TqVl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Mno7TqVl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_AkJqcOpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Mno7TqVl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Mno7TqVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XV39LpEH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_CdJFpjVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_k6Xv519v_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_sbVn9KMI, 0, m, &cIf_sbVn9KMI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_sbVn9KMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_n0Hw6DBy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_yS5RBvVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_HmGRb5OL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_qC2U41zC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_7W7iBDv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NpZSOkPu, HV_BINOP_POW, 0, m, &cBinop_NpZSOkPu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NpZSOkPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FTX5BwVq, 0, m, &cIf_FTX5BwVq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_l9xq9ipX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Xe6nViEc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wIQJB7Ap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yS5RBvVw, 0, m, &cIf_yS5RBvVw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yWAmWaT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0TvBiuB1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0TvBiuB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yS5RBvVw, 1, m, &cIf_yS5RBvVw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qC2U41zC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_l9xq9ipX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HmGRb5OL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_FTX5BwVq, 0, m, &cIf_FTX5BwVq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Xe6nViEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NpZSOkPu, HV_BINOP_POW, 1, m, &cBinop_NpZSOkPu_sendMessage);
  cMsg_7W7iBDv3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_FTX5BwVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_QEWmHoIb, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_k6Xv519v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sbVn9KMI, 1, m, &cIf_sbVn9KMI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_n0Hw6DBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g49e8CXU, HV_BINOP_GREATER_THAN, 1, m, &cBinop_g49e8CXU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5vXnMMFU, HV_BINOP_EQ, 1, m, &cBinop_5vXnMMFU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9K8ZvcJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DEs6jFCt, HV_BINOP_ADD, 0, m, &cBinop_DEs6jFCt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DEs6jFCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yWAmWaT5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wIQJB7Ap_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g49e8CXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FTX5BwVq, 1, m, &cIf_FTX5BwVq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5vXnMMFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Paz8J2kd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Paz8J2kd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QEWmHoIb, m);
}

void Heavy_WSTD_FL3NGR::cCast_RXe7869Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DEs6jFCt, HV_BINOP_ADD, 1, m, &cBinop_DEs6jFCt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_g49e8CXU, HV_BINOP_GREATER_THAN, 0, m, &cBinop_g49e8CXU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5vXnMMFU, HV_BINOP_EQ, 0, m, &cBinop_5vXnMMFU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FS1OvH71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CdJFpjVv, 0, m, &cVar_CdJFpjVv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qllialcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9K8ZvcJf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_9fg98XsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wVL6WBbc_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_cRgg51Q7, 0, m, &cIf_cRgg51Q7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_cRgg51Q7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Af8KkwXK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_8zN9hEAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_lBqbDnOO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_eAEYsVNn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_2Us5uwX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8ZtPqzU1, HV_BINOP_POW, 0, m, &cBinop_8ZtPqzU1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8ZtPqzU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DtUaYOQJ, 0, m, &cIf_DtUaYOQJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uPeYl2zG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_UhQEnS4f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5DRpRJfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4nmUWeaX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LuVO0jIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8zN9hEAB, 0, m, &cIf_8zN9hEAB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4nmUWeaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8zN9hEAB, 1, m, &cIf_8zN9hEAB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eAEYsVNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_uPeYl2zG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_lBqbDnOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_DtUaYOQJ, 0, m, &cIf_DtUaYOQJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UhQEnS4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8ZtPqzU1, HV_BINOP_POW, 1, m, &cBinop_8ZtPqzU1_sendMessage);
  cMsg_2Us5uwX2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_DtUaYOQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0etxgRZP_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_w43f0Juv_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_bheUUL8k_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_wVL6WBbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cRgg51Q7, 1, m, &cIf_cRgg51Q7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Af8KkwXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_90j0sO8b, HV_BINOP_GREATER_THAN, 1, m, &cBinop_90j0sO8b_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vMAFpfeq, HV_BINOP_EQ, 1, m, &cBinop_vMAFpfeq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2ezO50GI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6NmY9Awy, HV_BINOP_ADD, 0, m, &cBinop_6NmY9Awy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6NmY9Awy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5DRpRJfq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LuVO0jIV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_90j0sO8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DtUaYOQJ, 1, m, &cIf_DtUaYOQJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vMAFpfeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ejlqwzhJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ejlqwzhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0etxgRZP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_w43f0Juv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_bheUUL8k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ye96Cf9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9fg98XsS, 0, m, &cVar_9fg98XsS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_u4fhMIXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2ezO50GI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_gykzpKkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6NmY9Awy, HV_BINOP_ADD, 1, m, &cBinop_6NmY9Awy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_90j0sO8b, HV_BINOP_GREATER_THAN, 0, m, &cBinop_90j0sO8b_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vMAFpfeq, HV_BINOP_EQ, 0, m, &cBinop_vMAFpfeq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_PSy4ZjN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_w68c9h8Y_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Xe1rZl3n, 0, m, &cIf_Xe1rZl3n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_Xe1rZl3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1xGSnRJ3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_bR9yTzOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Wi5w4UR3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_4hjOaYbs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_EzgAuilc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JgVi75IU, HV_BINOP_POW, 0, m, &cBinop_JgVi75IU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JgVi75IU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BwXECmSn, 0, m, &cIf_BwXECmSn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1NhtC7xJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_BYombC7W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bLGbveO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bR9yTzOp, 0, m, &cIf_bR9yTzOp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xASYEg5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HGj5xVCl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HGj5xVCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bR9yTzOp, 1, m, &cIf_bR9yTzOp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4hjOaYbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_1NhtC7xJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Wi5w4UR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_BwXECmSn, 0, m, &cIf_BwXECmSn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BYombC7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JgVi75IU, HV_BINOP_POW, 1, m, &cBinop_JgVi75IU_sendMessage);
  cMsg_EzgAuilc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_BwXECmSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_FMtH8KsD, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_w68c9h8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Xe1rZl3n, 1, m, &cIf_Xe1rZl3n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1xGSnRJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fmo6QwAF, HV_BINOP_GREATER_THAN, 1, m, &cBinop_fmo6QwAF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WCwyKQGS, HV_BINOP_EQ, 1, m, &cBinop_WCwyKQGS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HMpDJn6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Z63UDtl, HV_BINOP_ADD, 0, m, &cBinop_2Z63UDtl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2Z63UDtl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xASYEg5E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bLGbveO1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fmo6QwAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BwXECmSn, 1, m, &cIf_BwXECmSn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WCwyKQGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IU6EHBgy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_IU6EHBgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_FMtH8KsD, m);
}

void Heavy_WSTD_FL3NGR::cCast_ZKKUvLKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Z63UDtl, HV_BINOP_ADD, 1, m, &cBinop_2Z63UDtl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fmo6QwAF, HV_BINOP_GREATER_THAN, 0, m, &cBinop_fmo6QwAF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WCwyKQGS, HV_BINOP_EQ, 0, m, &cBinop_WCwyKQGS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_c24SahvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PSy4ZjN2, 0, m, &cVar_PSy4ZjN2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6wMLehcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HMpDJn6b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_g3MSfzMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_uBN4WSmC, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_lPNyNuMM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lOMvxdFV, 0, m, &cSlice_lOMvxdFV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kbSUAQQy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_lOMvxdFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2MFJj5q6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2MFJj5q6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_07uGiGdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2MFJj5q6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_2MFJj5q6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vYb67GtK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_kbSUAQQy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_p70btcws, 0, m, &cSlice_p70btcws_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zSahA7GU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_p70btcws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0jHrMM4q_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0jHrMM4q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_FcUa4G6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0jHrMM4q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_0jHrMM4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lUebIi1X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_lPxxqSXY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_b3axF4mj, 0, m, &cSlice_b3axF4mj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_iTGeTTkX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_b3axF4mj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xIoVFdvX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xIoVFdvX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_sWwq4Svx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xIoVFdvX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_xIoVFdvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9uCzKMgo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_iTGeTTkX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jOCikP34, 0, m, &cSlice_jOCikP34_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_jOCikP34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_y6s20Qh1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_y6s20Qh1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_5u6iXPKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_y6s20Qh1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_y6s20Qh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Jp1EcPZO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_R3PnG3Zs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wl6NAanL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mQhulXmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t7hmf8nz, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_61Ya4hy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d8QCS00O, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_z4e7yteK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bZe1xwts, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_7fXDoyQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BuWfxXmM, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hIrAAPpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XesJWsw1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_XesJWsw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BT7LHGot, HV_BINOP_DIVIDE, 1, m, &cBinop_BT7LHGot_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JRZjMb7P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_8fjeiYmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_0O3x5HuJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EeArpBHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_8fjeiYmc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0O3x5HuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BT7LHGot, HV_BINOP_DIVIDE, 0, m, &cBinop_BT7LHGot_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JRZjMb7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EeArpBHO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BT7LHGot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sIILnuKR, HV_BINOP_MULTIPLY, 1, m, &cBinop_sIILnuKR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sIILnuKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d37ikYSD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tmYZbobL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_T8jhL992_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IDJbjuNv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_FIwf1qcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QyClOcKx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ELgY41nz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_GCFXHAhk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GCFXHAhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sIILnuKR, HV_BINOP_MULTIPLY, 0, m, &cBinop_sIILnuKR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OXmMDbVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_04VEuF3H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_04VEuF3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HFdOPZC9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_EevnIgGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DUWWoktu, 1, m, &cVar_DUWWoktu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_DUWWoktu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S8hjPQPO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_kBY8MyzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UuPeAPnD, HV_BINOP_MULTIPLY, 1, m, &cBinop_UuPeAPnD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_puoBZh9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kBY8MyzW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_s62QpUmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jNj9Ity7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jNj9Ity7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IwBTOsIE, HV_BINOP_MULTIPLY, 1, m, &cBinop_IwBTOsIE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ElkyOoVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O8AXn63D, HV_BINOP_MULTIPLY, 1, m, &cBinop_O8AXn63D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sG7PjWHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ElkyOoVF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aMxMHbxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xADUGgE6, HV_BINOP_MULTIPLY, 1, m, &cBinop_xADUGgE6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tY0Etw31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_99h9LARQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_99h9LARQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UR5kLfpL, HV_BINOP_MULTIPLY, 1, m, &cBinop_UR5kLfpL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_yx8IaTZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tw7sEFpI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ELgY41nz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RAPwEFrQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_8vb5uucG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_OXmMDbVf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_d37ikYSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_T8jhL992_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tmYZbobL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_FIwf1qcc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_IDJbjuNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6XoHl93b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_QyClOcKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BjoU7pJr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_4fBv4g5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_646ttw9J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_HFdOPZC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XIFfVwys_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XIFfVwys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AZmYeAfo, HV_BINOP_MULTIPLY, 1, m, &cBinop_AZmYeAfo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AZmYeAfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ItcvzFrX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ItcvzFrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4fBv4g5m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_S8hjPQPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zglxaBbH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zglxaBbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H1U9DVsc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wu3XNwXg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6gu9Pv2A_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DofPekUe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YhIM0Aso_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2i7KYkgF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UuPeAPnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R3PnG3Zs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IwBTOsIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mQhulXmE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_O8AXn63D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_61Ya4hy4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xADUGgE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z4e7yteK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UR5kLfpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7fXDoyQZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_raE4vdRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yx8IaTZr, 0, m, &cVar_yx8IaTZr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sk9IPKPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8vb5uucG, 1, m, &cVar_8vb5uucG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DofPekUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O8AXn63D, HV_BINOP_MULTIPLY, 0, m, &cBinop_O8AXn63D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_H1U9DVsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_2i7KYkgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UuPeAPnD, HV_BINOP_MULTIPLY, 0, m, &cBinop_UuPeAPnD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6gu9Pv2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xADUGgE6, HV_BINOP_MULTIPLY, 0, m, &cBinop_xADUGgE6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YhIM0Aso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IwBTOsIE, HV_BINOP_MULTIPLY, 0, m, &cBinop_IwBTOsIE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Wu3XNwXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UR5kLfpL, HV_BINOP_MULTIPLY, 0, m, &cBinop_UR5kLfpL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_RAPwEFrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DUWWoktu, 0, m, &cVar_DUWWoktu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tw7sEFpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8vb5uucG, 0, m, &cVar_8vb5uucG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Gpj0Ytzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_99Fa0uzR, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_8cvy2UXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JhufN57T, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_BMdBkxSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TmYg2HiC, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_JhIomaOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Fv8yZ5fR, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_XXlg6M65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TbybSegV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_TbybSegV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1oWeJjef, HV_BINOP_DIVIDE, 1, m, &cBinop_1oWeJjef_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hDH0enCO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_jJgvWbEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_FzcNzRfK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_z0TblLSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_jJgvWbEH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FzcNzRfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1oWeJjef, HV_BINOP_DIVIDE, 0, m, &cBinop_1oWeJjef_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hDH0enCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z0TblLSP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1oWeJjef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pe1Wvv0l, HV_BINOP_MULTIPLY, 1, m, &cBinop_Pe1Wvv0l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Pe1Wvv0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rQy9KxKB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nMF9b05X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_BVcxjZ4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WhpHKK1g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_vLsSExJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2XB8mP2X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HcBf5YGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_6GG2rTDq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6GG2rTDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pe1Wvv0l, HV_BINOP_MULTIPLY, 0, m, &cBinop_Pe1Wvv0l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SQUCrSxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_fcIy19z8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fcIy19z8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KEENpj1N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Jq2PXNMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vwrWpjVm, HV_BINOP_MULTIPLY, 1, m, &cBinop_vwrWpjVm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ApgILcM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gDf2zTic, 1, m, &cVar_gDf2zTic_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KcsXGbrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zGu6dMTZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_zGu6dMTZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MldnFj0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_U9DaGo0q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_U9DaGo0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4O5N1ANy, HV_BINOP_MULTIPLY, 1, m, &cBinop_4O5N1ANy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_gDf2zTic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_teLiituH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_38H3fZmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2sl0AobA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_HcBf5YGU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Cyq6qGOa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_1FoDb7Vs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_SQUCrSxf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rQy9KxKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_BVcxjZ4z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nMF9b05X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_vLsSExJV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_WhpHKK1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XFujlyht_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_2XB8mP2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fP9EwrOL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_D4vbHMsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4WYNL8Pw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_KEENpj1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_nwY4Dlbe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nwY4Dlbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wNnRonbV, HV_BINOP_MULTIPLY, 1, m, &cBinop_wNnRonbV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wNnRonbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mIgJobuD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mIgJobuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_D4vbHMsQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_teLiituH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_H5iY7FRj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_H5iY7FRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p3nvLGtv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yLg1YMTY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iJWQ52TH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zUHKWJiK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_x6wdgMTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gpj0Ytzq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vwrWpjVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8cvy2UXv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zGu6dMTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BMdBkxSb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_4O5N1ANy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JhIomaOy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_B0QHtppM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1FoDb7Vs, 1, m, &cVar_1FoDb7Vs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OAYqYTXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_38H3fZmM, 0, m, &cVar_38H3fZmM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Cyq6qGOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gDf2zTic, 0, m, &cVar_gDf2zTic_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2sl0AobA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1FoDb7Vs, 0, m, &cVar_1FoDb7Vs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iJWQ52TH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vwrWpjVm, HV_BINOP_MULTIPLY, 0, m, &cBinop_vwrWpjVm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yLg1YMTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zGu6dMTZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_zGu6dMTZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zUHKWJiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x6wdgMTN, HV_BINOP_MULTIPLY, 0, m, &cBinop_x6wdgMTN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_p3nvLGtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4O5N1ANy, HV_BINOP_MULTIPLY, 0, m, &cBinop_4O5N1ANy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_C6Vpc2K8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WhWUZgV5, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_zUPgZmfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iuBgOLlq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_5QFtGr0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZEbKIH59, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_7g5fmide_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VMkof5Xc, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ArSvzciA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KByNcpG1, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_cF2Z1QNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KKQZ9iwB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_KKQZ9iwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KEMp9qUK, HV_BINOP_DIVIDE, 1, m, &cBinop_KEMp9qUK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4kXGGyDm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_oyyTl5TN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ULG6KbmA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tN35SCTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_oyyTl5TN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ULG6KbmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KEMp9qUK, HV_BINOP_DIVIDE, 0, m, &cBinop_KEMp9qUK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4kXGGyDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tN35SCTU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KEMp9qUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_25TzX6pn, HV_BINOP_MULTIPLY, 1, m, &cBinop_25TzX6pn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_25TzX6pn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pRj84CNV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CNVjZZta_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_2zN1lIcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3hGErnMf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_chXjKIzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_htJB2Mb8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_o3veTPkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_GLkQik6V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GLkQik6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_25TzX6pn, HV_BINOP_MULTIPLY, 0, m, &cBinop_25TzX6pn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5pMNT3Hm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_T51KrbNG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_T51KrbNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aXp1vfhu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_x8UCPp6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7NzAfUpu, HV_BINOP_MULTIPLY, 1, m, &cBinop_7NzAfUpu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nlz8AFBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FpaZ86bS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FpaZ86bS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_x8UCPp6W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_cBXmw3uP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MPExGg30_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MPExGg30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YmM9VfUZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_YmM9VfUZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wyBz5g2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b52Wywww, HV_BINOP_MULTIPLY, 1, m, &cBinop_b52Wywww_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bF1z5EvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Fa6Z91mb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Fa6Z91mb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_wyBz5g2L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sYEA4GM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lbJnZ10G, 1, m, &cVar_lbJnZ10G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mqB5t0Rm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w4qPknPe, HV_BINOP_MULTIPLY, 1, m, &cBinop_w4qPknPe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_v2Mm91PR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OG7B4Ewm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OG7B4Ewm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jp0RJTyd, HV_BINOP_MULTIPLY, 1, m, &cBinop_jp0RJTyd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_lbJnZ10G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4LMskkkA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_yO68P4yd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rQsEYcuy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_o3veTPkq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g8q6Hptu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_sggnTu43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_5pMNT3Hm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CNVjZZta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_chXjKIzs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pRj84CNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_2zN1lIcP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_3hGErnMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HTC7zDiD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_htJB2Mb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_73Y7URcs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_zZvZ6Jlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_c8UeJwBv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_aXp1vfhu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XJHJLQ5y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XJHJLQ5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DXWhmc5O, HV_BINOP_MULTIPLY, 1, m, &cBinop_DXWhmc5O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DXWhmc5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uxyIF4X1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uxyIF4X1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zZvZ6Jlm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_4LMskkkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_GeGRbVYE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GeGRbVYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a9rQrJzZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MxrCKflB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wIQ0IISG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wImXfWKG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iVtTIrQN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a6Nfd0dn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7NzAfUpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C6Vpc2K8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YmM9VfUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zUPgZmfi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_b52Wywww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5QFtGr0k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_w4qPknPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7g5fmide_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_jp0RJTyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ArSvzciA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_eWe3GzCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sggnTu43, 1, m, &cVar_sggnTu43_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EMYEyWwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yO68P4yd, 0, m, &cVar_yO68P4yd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wImXfWKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b52Wywww, HV_BINOP_MULTIPLY, 0, m, &cBinop_b52Wywww_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_a9rQrJzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_a6Nfd0dn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7NzAfUpu, HV_BINOP_MULTIPLY, 0, m, &cBinop_7NzAfUpu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wIQ0IISG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w4qPknPe, HV_BINOP_MULTIPLY, 0, m, &cBinop_w4qPknPe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iVtTIrQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YmM9VfUZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_YmM9VfUZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MxrCKflB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jp0RJTyd, HV_BINOP_MULTIPLY, 0, m, &cBinop_jp0RJTyd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rQsEYcuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sggnTu43, 0, m, &cVar_sggnTu43_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_g8q6Hptu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lbJnZ10G, 0, m, &cVar_lbJnZ10G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0etxgRZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g3MSfzMK, 1, m, &cIf_g3MSfzMK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_oK1GXgEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uBN4WSmC, m);
}

void Heavy_WSTD_FL3NGR::cBinop_w43f0Juv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oK1GXgEu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_bheUUL8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g3MSfzMK, 0, m, &cIf_g3MSfzMK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Fw8Fo8LY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WGyrRjnz, HV_BINOP_DIVIDE, 0, m, &cBinop_WGyrRjnz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_QK9HPWHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ivUGIjlW, HV_BINOP_DIVIDE, 1, m, &cBinop_ivUGIjlW_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WGyrRjnz, HV_BINOP_DIVIDE, 1, m, &cBinop_WGyrRjnz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_kh9CXfGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8DnCSUmq, HV_BINOP_DIVIDE, 0, m, &cBinop_8DnCSUmq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_G0aw69Cc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8DnCSUmq, HV_BINOP_DIVIDE, 1, m, &cBinop_8DnCSUmq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_l6IAIh5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ivUGIjlW, HV_BINOP_DIVIDE, 0, m, &cBinop_ivUGIjlW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sjmjt5RR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fw8Fo8LY, 0, m, &cVar_Fw8Fo8LY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_H4v9PUn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QK9HPWHL, 0, m, &cVar_QK9HPWHL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ivUGIjlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_kh9CXfGg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WGyrRjnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_G0aw69Cc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8DnCSUmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_JAcFIbMS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_li6Rk8RO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_gNPId3Fu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_74IKEAce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_h98DwDO9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JAcFIbMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_74IKEAce_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_h98DwDO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_li6Rk8RO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gNPId3Fu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_igq7UHW9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_d8rkvGUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BtxWcmO1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_tSFVD0RI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A54e3EX2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_gsGErtDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bf0eK5TS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_UCNTejzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OjQHnrml_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_OQLlLDYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EbqG8xtn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_aDWscPky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4yMG3jy2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ERWOYUum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SUw1CVTv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_bhjeQmnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w7uHx9KK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_SDJfNy7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oUYboJ40_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_2mosq0lA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oTlEmdAd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_a9RSAfSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cqhfUCBg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_htHpKDJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wCAP3QWd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_oX1g47Um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ldfw9ig6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ldfw9ig6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_Z4e3D788, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_RcWYu72r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oufmxJfL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_oufmxJfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_k8b6PuZo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_kII3SEqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ORrUf5Aa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_lfIxEpVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tv4tnXVW_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_v6T97sSV, m);
}

void Heavy_WSTD_FL3NGR::cBinop_k8b6PuZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_EKUyDbvr, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ORrUf5Aa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lfIxEpVY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tv4tnXVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QzbsP73z, m);
}

void Heavy_WSTD_FL3NGR::cMsg_zfev7x8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_E5vbomhz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_E5vbomhz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_MhfIG2gi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_866y0rLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NZTrwapr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_deSGx6H9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6uOCUu0y_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ljrZxAHJ, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MhfIG2gi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tY2fesmt, m);
}

void Heavy_WSTD_FL3NGR::cMsg_NZTrwapr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_deSGx6H9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6uOCUu0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5gAyENIo, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wynPy2Mq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7ii9EHlX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7ii9EHlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_tNdrPgJ6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_DyfUBsrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XkQq7WYM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_7MjfhYuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vyTHLIGf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_tNdrPgJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_e5DTiX4G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_e5DTiX4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gkBvtMGl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4rzMUghX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gkBvtMGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MNtChBKT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4rzMUghX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YpHPmESd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MNtChBKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_la9cNuQ8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YpHPmESd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sbQLtNS4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sbQLtNS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7blgWq5b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_la9cNuQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_DyfUBsrh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7blgWq5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_7MjfhYuW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_k5T7L2Rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2K1qhtvF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2K1qhtvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6moulhAH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_UPJcT203_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vXmE1B4g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_vXmE1B4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_fQKwY6ou_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_nNUxFM1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nNUxFM1U, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_v2NtUn1v, 0, m, &cDelay_v2NtUn1v_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nNUxFM1U, 0, m, &cDelay_nNUxFM1U_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6ddkhNKi, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_v2NtUn1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_v2NtUn1v, m);
  cMsg_6ndboPxx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_2DRw0Hjs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Zur3HGuO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_6vXRyM0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BSyx9H17_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_C8kCittK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VFEy8guI_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nNUxFM1U, 2, m, &cDelay_nNUxFM1U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UaUFxzmC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_BSyx9H17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_C8kCittK, 0, m, &hTable_C8kCittK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fQKwY6ou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_6vXRyM0J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6ndboPxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_C8kCittK, 0, m, &hTable_C8kCittK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UaUFxzmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nNUxFM1U, 0, m, &cDelay_nNUxFM1U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_VFEy8guI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_v2NtUn1v, 2, m, &cDelay_v2NtUn1v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Zur3HGuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6ddkhNKi, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_XNntXUPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xXW28WjR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_xXW28WjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_MGsS2aWi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_6gtsRis4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6gtsRis4, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zQgZdZ8N, 0, m, &cDelay_zQgZdZ8N_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6gtsRis4, 0, m, &cDelay_6gtsRis4_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_qCXwFK6a, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_zQgZdZ8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zQgZdZ8N, m);
  cMsg_nz2tErLz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_40mctSui_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_1FwhRvUC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_PfPEZJes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W5lXA9Dh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_khED8MJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nu1Pl21I_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6gtsRis4, 2, m, &cDelay_6gtsRis4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n2lVNYOQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_W5lXA9Dh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_khED8MJr, 0, m, &hTable_khED8MJr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MGsS2aWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_PfPEZJes_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nz2tErLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_khED8MJr, 0, m, &hTable_khED8MJr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_n2lVNYOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6gtsRis4, 0, m, &cDelay_6gtsRis4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Nu1Pl21I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_zQgZdZ8N, 2, m, &cDelay_zQgZdZ8N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1FwhRvUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_qCXwFK6a, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_pvcGvtUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q3jqAMMN, HV_BINOP_MULTIPLY, 0, m, &cBinop_Q3jqAMMN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0iJMrz5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4WgCdHWh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_4WgCdHWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T7014UiW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Q3jqAMMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Hkz2rFXY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2dOUnq3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q3jqAMMN, HV_BINOP_MULTIPLY, 1, m, &cBinop_Q3jqAMMN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_T7014UiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2dOUnq3Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Hkz2rFXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gBeEko2A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gBeEko2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7dIt5Urn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_FL7tyaOZ, m);
}

void Heavy_WSTD_FL3NGR::cBinop_7dIt5Urn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pCJZsCfL, m);
}

void Heavy_WSTD_FL3NGR::cVar_cnLA9BwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5hRKySDL, HV_BINOP_MULTIPLY, 0, m, &cBinop_5hRKySDL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nvpLXneX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qB7RGhw9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_qB7RGhw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pE4YcQiD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5hRKySDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_fORUbRKg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_icVPTpDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5hRKySDL, HV_BINOP_MULTIPLY, 1, m, &cBinop_5hRKySDL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_pE4YcQiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_icVPTpDK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fORUbRKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_JXD7dHgZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JXD7dHgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_u7P1Ay0R_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fJQLmtB2, m);
}

void Heavy_WSTD_FL3NGR::cBinop_u7P1Ay0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_gIeuRhAR, m);
}

void Heavy_WSTD_FL3NGR::cMsg_6moulhAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZQokkPCy, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_dN5DrK8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_LBlnEBsy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_veKBjvTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_dN5DrK8a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_E3SWta4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3mMYAQJK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GoMLS1i5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pAsaMdY5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pAsaMdY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DtVbftSO, HV_BINOP_MULTIPLY, 1, m, &cBinop_DtVbftSO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3mMYAQJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_GoMLS1i5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DtVbftSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LVVdWq4r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LBlnEBsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DtVbftSO, HV_BINOP_MULTIPLY, 0, m, &cBinop_DtVbftSO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_LVVdWq4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sCrIV8Br, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_c8Oyr2tZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_n7YaiwzE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_n7YaiwzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E3SWta4h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_veKBjvTF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_orKQA9t1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_b3R8ZkGu, 0, m, &cSlice_b3R8ZkGu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ckunhnTQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_b3R8ZkGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OObV5VrL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OObV5VrL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_6c5thhST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OObV5VrL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_OObV5VrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kXRJ6daa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_ckunhnTQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4VD7l3Dj, 0, m, &cSlice_4VD7l3Dj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_i6i959y3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_4VD7l3Dj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IoPO8ICp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IoPO8ICp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_GqAVtLzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IoPO8ICp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_IoPO8ICp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JbVasEvL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_i6i959y3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DytDCjtf, 0, m, &cSlice_DytDCjtf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KZDI0rrC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_DytDCjtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_br3J8leB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_br3J8leB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_nbj0MVZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_br3J8leB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_br3J8leB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZqQbFv3u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_KZDI0rrC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_caK1y9jo, 0, m, &cSlice_caK1y9jo_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_caK1y9jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_n7a14ldE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_n7a14ldE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_V7Ne2TXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_n7a14ldE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_n7a14ldE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JfyRyJU7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_XkQq7WYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mI4Nc58Q, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_vyTHLIGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qQs5IpK7, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_FXcTMC8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0CowwxE2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0CowwxE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_lYbCV9IN, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_IM71WQqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GgOe6Nmy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_GgOe6Nmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qYuDxS9C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_jHQZFu3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iy8C9ZbN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_9OqbJcdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Gi1dYdFK_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_vx5biWG8, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qYuDxS9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FxQqw34d, m);
}

void Heavy_WSTD_FL3NGR::cMsg_iy8C9ZbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9OqbJcdh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Gi1dYdFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xUC7ZuNs, m);
}

void Heavy_WSTD_FL3NGR::cMsg_KnjEulG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4QpVC3ds_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_4QpVC3ds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_vYVQQ58Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_NkoH3YKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OrMmCN2F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_1WZ8zjx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6wZxaxj3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_IYsELmhF, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vYVQQ58Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vyHDjAJT, m);
}

void Heavy_WSTD_FL3NGR::cMsg_OrMmCN2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1WZ8zjx2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6wZxaxj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_WSjbjGf1, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KHHftBP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_AqyNVqwv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AqyNVqwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_zVLEsCVt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_A5N5cCgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RxNcVetB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_FX65kvvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mNLxSJPq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zVLEsCVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fy6Eqbxa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fy6Eqbxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ba3sX047_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i6vSYOh6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_i6vSYOh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5m8RAvF0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_Ba3sX047_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qHYvH57s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qHYvH57s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AyvVjmL6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5m8RAvF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pN5sn0ZY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pN5sn0ZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Nz9PPYsa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AyvVjmL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_A5N5cCgQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Nz9PPYsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_FX65kvvL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_u8eJKNYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_pbld121J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pbld121J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uwRER82W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_1nCQjIS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uSGXfewj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_uSGXfewj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_hL7h5kPX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_IGgfMmJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IGgfMmJi, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zgZ4GyiL, 0, m, &cDelay_zgZ4GyiL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IGgfMmJi, 0, m, &cDelay_IGgfMmJi_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ocz1EK2Y, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_zgZ4GyiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zgZ4GyiL, m);
  cMsg_GKfFiHlw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_DNohWJzG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Kllhvnmd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_C6Pwmf8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7wIAzh2v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_NjSNqTNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wwqSyEMJ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IGgfMmJi, 2, m, &cDelay_IGgfMmJi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uAeNBwfP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7wIAzh2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_NjSNqTNT, 0, m, &hTable_NjSNqTNT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hL7h5kPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_C6Pwmf8j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GKfFiHlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_NjSNqTNT, 0, m, &hTable_NjSNqTNT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_uAeNBwfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IGgfMmJi, 0, m, &cDelay_IGgfMmJi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wwqSyEMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_zgZ4GyiL, 2, m, &cDelay_zgZ4GyiL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Kllhvnmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ocz1EK2Y, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_FfKWv1l6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_raPLYLxS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_raPLYLxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_uHb3ps5c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_tUmgcNNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tUmgcNNU, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4TiZVvkt, 0, m, &cDelay_4TiZVvkt_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tUmgcNNU, 0, m, &cDelay_tUmgcNNU_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_W4T6nldM, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_4TiZVvkt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4TiZVvkt, m);
  cMsg_XNn8OtJi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_vROQOCKC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_80Jv0Pnc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_ouZR37XP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MUM13GJh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_ZpHdSDWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7CwuRxA0_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tUmgcNNU, 2, m, &cDelay_tUmgcNNU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SzpQXjvs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MUM13GJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ZpHdSDWr, 0, m, &hTable_ZpHdSDWr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uHb3ps5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_ouZR37XP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XNn8OtJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ZpHdSDWr, 0, m, &hTable_ZpHdSDWr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_SzpQXjvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tUmgcNNU, 0, m, &cDelay_tUmgcNNU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7CwuRxA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_4TiZVvkt, 2, m, &cDelay_4TiZVvkt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_80Jv0Pnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_W4T6nldM, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_Yx6KxmDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2yTHPsDT, HV_BINOP_MULTIPLY, 0, m, &cBinop_2yTHPsDT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_VFWFLOtt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_B7IuYoLi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_B7IuYoLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WTJYkhH4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2yTHPsDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hSoFI6cU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mbwWgOun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2yTHPsDT, HV_BINOP_MULTIPLY, 1, m, &cBinop_2yTHPsDT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WTJYkhH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mbwWgOun_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hSoFI6cU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_HGWMgPph_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HGWMgPph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_WEI5g6kI_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QcjyW8sX, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WEI5g6kI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3y8zeeFF, m);
}

void Heavy_WSTD_FL3NGR::cVar_dLwLzVT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qyM5T2ni, HV_BINOP_MULTIPLY, 0, m, &cBinop_qyM5T2ni_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_azoBWGBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2lWhidU7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_2lWhidU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E4aCy0T3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qyM5T2ni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Pkd0ClQd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hzx9X5xy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qyM5T2ni, HV_BINOP_MULTIPLY, 1, m, &cBinop_qyM5T2ni_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_E4aCy0T3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hzx9X5xy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Pkd0ClQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4Mw8Dcxc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4Mw8Dcxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_V0PLQsOT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_TUWfJ5do, m);
}

void Heavy_WSTD_FL3NGR::cBinop_V0PLQsOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4Fg5KgOT, m);
}

void Heavy_WSTD_FL3NGR::cMsg_uwRER82W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bJi9cLtr, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_EBcP2iRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_OpEnrHcs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4e4MjZ5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9VMSYjEQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0RZET3tD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_EBcP2iRb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UEjLWbKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_JozKResB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JozKResB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YtRxZLQC, HV_BINOP_MULTIPLY, 1, m, &cBinop_YtRxZLQC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9VMSYjEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_UEjLWbKX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YtRxZLQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TmCecq3l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OpEnrHcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YtRxZLQC, HV_BINOP_MULTIPLY, 0, m, &cBinop_YtRxZLQC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_TmCecq3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_78MEMfpl, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_FCaOEpGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_a82Xmkc0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_a82Xmkc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4e4MjZ5k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0RZET3tD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Ejk9mz3p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uReuzCqY, 0, m, &cSlice_uReuzCqY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oRlsvaff_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_uReuzCqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_V7VrJzaU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_V7VrJzaU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_lPXMU2Kn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V7VrJzaU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_V7VrJzaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YL03UqPq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_oRlsvaff_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_K4fCmMVQ, 0, m, &cSlice_K4fCmMVQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VyY1osCG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_K4fCmMVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_InGiOweI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_InGiOweI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_52Mv8V6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_InGiOweI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_InGiOweI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gnjvJDqY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_VyY1osCG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KL6UeIpx, 0, m, &cSlice_KL6UeIpx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_12NcLPW8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_KL6UeIpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iRVaRfN1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iRVaRfN1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_lSYmohsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iRVaRfN1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_iRVaRfN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vuFNOonz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_12NcLPW8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_t5FRDCdu, 0, m, &cSlice_t5FRDCdu_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_t5FRDCdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6h8MTY4a_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6h8MTY4a_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_kkAvBEF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6h8MTY4a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_6h8MTY4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Rb2s26pO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_RxNcVetB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yov4eQZX, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mNLxSJPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vabtI1Tl, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_0HrmDyTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_laQjXWAi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_laQjXWAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_OGWaKAiR, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_5o2p56Vz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4BaR5SSm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_4BaR5SSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_WuHkbylb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_wZNCwqpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pNKLjZyL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_WwsVClCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jTvzP0xA_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_aOZDODzI, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WuHkbylb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_UIa9J7JB, m);
}

void Heavy_WSTD_FL3NGR::cMsg_pNKLjZyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WwsVClCx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jTvzP0xA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_k1vrykDG, m);
}

void Heavy_WSTD_FL3NGR::cMsg_0LsRW53K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XeUnhjMl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_XeUnhjMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0XCrT44d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_cRDVCZHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ekq0ZPXO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_YS673t6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9qVijHh7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_A2Fjr5pw, m);
}

void Heavy_WSTD_FL3NGR::cBinop_0XCrT44d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CEArNN8P, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ekq0ZPXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YS673t6A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9qVijHh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_v1Pgv8zQ, m);
}

void Heavy_WSTD_FL3NGR::cBinop_aIamgcMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zYzmzkWR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zYzmzkWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_jjPylYn9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_q5r3Ndo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9b7UwG01_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_Nyv7s16G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nQA1Z1i7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_jjPylYn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_q0tJ7YFO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_q0tJ7YFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YG33qABR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u2MMZUtc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_u2MMZUtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Akzp29CB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_YG33qABR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_q54HExge_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_q54HExge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gFhHeHaw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Akzp29CB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EmNfK8CO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EmNfK8CO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IDb2aqE5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gFhHeHaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_q5r3Ndo5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IDb2aqE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_Nyv7s16G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5SZYGL9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_1lnCinge_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1lnCinge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_80BwbKX0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_qSjdPyRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BMgd18TE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_BMgd18TE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_uAYjkfZW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_DoRP9RUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DoRP9RUc, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wQ35vTCU, 0, m, &cDelay_wQ35vTCU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DoRP9RUc, 0, m, &cDelay_DoRP9RUc_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_1sVRzSfE, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_wQ35vTCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wQ35vTCU, m);
  cMsg_ZEPazDl3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_6XVfDqYp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ouKYwbAk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_n2qv97NG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EzC5BZoU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_Rjs9xVEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xd6hHisO_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DoRP9RUc, 2, m, &cDelay_DoRP9RUc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pzi8fgRe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EzC5BZoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Rjs9xVEQ, 0, m, &hTable_Rjs9xVEQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uAYjkfZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_n2qv97NG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZEPazDl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Rjs9xVEQ, 0, m, &hTable_Rjs9xVEQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Pzi8fgRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DoRP9RUc, 0, m, &cDelay_DoRP9RUc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xd6hHisO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_wQ35vTCU, 2, m, &cDelay_wQ35vTCU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ouKYwbAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_1sVRzSfE, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_QUSWiMRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ozGxSSBT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ozGxSSBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Czn5Htz0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_p5WuNYfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_p5WuNYfL, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JWYTGtWG, 0, m, &cDelay_JWYTGtWG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_p5WuNYfL, 0, m, &cDelay_p5WuNYfL_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_2iS43VKo, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_JWYTGtWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JWYTGtWG, m);
  cMsg_mZu5P6PZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_PtMdZUzb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_XCmKeeqr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_oSc92L4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cm79buYs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_c0RaC2FK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UEVnX7xl_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_p5WuNYfL, 2, m, &cDelay_p5WuNYfL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Zhygj0ih_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Cm79buYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_c0RaC2FK, 0, m, &hTable_c0RaC2FK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Czn5Htz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_oSc92L4H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mZu5P6PZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_c0RaC2FK, 0, m, &hTable_c0RaC2FK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Zhygj0ih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_p5WuNYfL, 0, m, &cDelay_p5WuNYfL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_UEVnX7xl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_JWYTGtWG, 2, m, &cDelay_JWYTGtWG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XCmKeeqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_2iS43VKo, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_P4nZo3zF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UIvrNqDc, HV_BINOP_MULTIPLY, 0, m, &cBinop_UIvrNqDc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_UMJqvSwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wZWjQdL0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_wZWjQdL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TBYHrtXK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UIvrNqDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_TuOy4Scf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sJkP7Yoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UIvrNqDc, HV_BINOP_MULTIPLY, 1, m, &cBinop_UIvrNqDc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_TBYHrtXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_sJkP7Yoh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TuOy4Scf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Lhu6i7Gr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Lhu6i7Gr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_3k9GNi3T_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_pZsZScRd, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3k9GNi3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3M5XRdwo, m);
}

void Heavy_WSTD_FL3NGR::cVar_B48xwbUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FQ4LNV6F, HV_BINOP_MULTIPLY, 0, m, &cBinop_FQ4LNV6F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YBZHPlA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_811N790c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_811N790c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zIdt85NV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FQ4LNV6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_yTcokQCo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4p1aFjNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FQ4LNV6F, HV_BINOP_MULTIPLY, 1, m, &cBinop_FQ4LNV6F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zIdt85NV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_4p1aFjNE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yTcokQCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XI4p0ll7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XI4p0ll7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_0X3jh8KB_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_s7TqJwTl, m);
}

void Heavy_WSTD_FL3NGR::cBinop_0X3jh8KB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wihsT90Y, m);
}

void Heavy_WSTD_FL3NGR::cMsg_80BwbKX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5MvTnuy9, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_oh31RZp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_R0Fk8I2l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ku5tKt8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_oh31RZp7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7M0iViox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_PmnqPaPl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_udTycMwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_2XG8nCA4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2XG8nCA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JjzGsSYX, HV_BINOP_MULTIPLY, 1, m, &cBinop_JjzGsSYX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PmnqPaPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_udTycMwK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JjzGsSYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HIGvA8NK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_R0Fk8I2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JjzGsSYX, HV_BINOP_MULTIPLY, 0, m, &cBinop_JjzGsSYX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HIGvA8NK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uONvVTHG, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_oK3agFOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_q4K4iQj2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_q4K4iQj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7M0iViox_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ku5tKt8A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_zHSpJXSn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xqFlHdOM, 0, m, &cSlice_xqFlHdOM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HniEQF1Z_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_xqFlHdOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_t03qarDe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_t03qarDe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_zCRStbNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_t03qarDe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_t03qarDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QetMiaZf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_HniEQF1Z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dVNPQfre, 0, m, &cSlice_dVNPQfre_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4v3o73fB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_dVNPQfre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GvGBLUK4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GvGBLUK4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_j3AtuhWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GvGBLUK4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_GvGBLUK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DC24oYFS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_4v3o73fB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pUwqjxQ7, 0, m, &cSlice_pUwqjxQ7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FFp4eJMP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_pUwqjxQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_e1KpWVXs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_e1KpWVXs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_j3iZ6a7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_e1KpWVXs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_e1KpWVXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3BKKqEk2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_FFp4eJMP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Hrw3y7i4, 0, m, &cSlice_Hrw3y7i4_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Hrw3y7i4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yE5cTazE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yE5cTazE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_xrkQ97I6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yE5cTazE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_yE5cTazE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_F9D5RrrA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_9b7UwG01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z3pdwBDT, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_nQA1Z1i7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_REuKhhAj, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6UnuBLrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_p1vIKh6m_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lPNyNuMM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mR9ZddFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_p1vIKh6m_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lPNyNuMM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_MWNJX415_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_p1vIKh6m_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lPNyNuMM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_X6afB3m4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_p1vIKh6m_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lPNyNuMM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_igq7UHW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_p1vIKh6m_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_lPNyNuMM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_65xUxDu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_PxvTWe99, 0, m, &cVar_PxvTWe99_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6q0iPPRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_XzaQTmVg, 0, m, &cVar_XzaQTmVg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zFPnH1Bx, 0, m, &cVar_zFPnH1Bx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Htn3ynaP, 0, m, &cVar_Htn3ynaP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OjQHnrml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_orKQA9t1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_BtxWcmO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_orKQA9t1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_A54e3EX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_orKQA9t1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Bf0eK5TS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_orKQA9t1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_niLHuVPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UCNTejzr, 0, m, &cVar_UCNTejzr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1XxUVbSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d8rkvGUY, 0, m, &cVar_d8rkvGUY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KAiYmUEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gsGErtDB, 0, m, &cVar_gsGErtDB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_w7uHx9KK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ejk9mz3p_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_EbqG8xtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ejk9mz3p_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_4yMG3jy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ejk9mz3p_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_SUw1CVTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ejk9mz3p_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_6XK4Rvs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bhjeQmnl, 0, m, &cVar_bhjeQmnl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DkRqtAcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OQLlLDYU, 0, m, &cVar_OQLlLDYU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TmlpHiYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ERWOYUum, 0, m, &cVar_ERWOYUum_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wCAP3QWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zHSpJXSn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_oUYboJ40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zHSpJXSn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_oTlEmdAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zHSpJXSn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_cqhfUCBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zHSpJXSn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_9Gu3yAXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_htHpKDJi, 0, m, &cVar_htHpKDJi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zCuRAvq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SDJfNy7o, 0, m, &cVar_SDJfNy7o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vz3TC23q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a9RSAfSx, 0, m, &cVar_a9RSAfSx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_VViIrxPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XzaQTmVg, 0, m, &cVar_XzaQTmVg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_aBegCth4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zFPnH1Bx, 0, m, &cVar_zFPnH1Bx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_B112oPvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Htn3ynaP, 0, m, &cVar_Htn3ynaP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_NWfW1UmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kVqVABTS, 0, m, &cVar_kVqVABTS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_p2dhTpqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QQjvK1Zt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GVapInoP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_nKW1Rqm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b9ZNfeqn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VJ5yYQln_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YZdlBUQQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_X4ADXnuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_szV1RtAS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UrPdml2T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YMJKkOWT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_wgXgN0rM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gQGa5OvN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_upYOEWVz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H9NHxlZQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_C5GS5nig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uCaVvGp0_sendMessage(_c, 0, m);
  cMsg_Ed7ZY3oz_sendMessage(_c, 0, m);
  cMsg_vzVG2Sso_sendMessage(_c, 0, m);
  cMsg_hIrAAPpX_sendMessage(_c, 0, m);
  cMsg_XXlg6M65_sendMessage(_c, 0, m);
  cMsg_cF2Z1QNa_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VzkCVeMS, 0, m, &cVar_VzkCVeMS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kVqVABTS, 0, m, &cVar_kVqVABTS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AjgpHURx, 0, m, &cVar_AjgpHURx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yx8IaTZr, 0, m, &cVar_yx8IaTZr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_38H3fZmM, 0, m, &cVar_38H3fZmM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yO68P4yd, 0, m, &cVar_yO68P4yd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lCEBfqy7, 0, m, &cVar_lCEBfqy7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_430xMTWr, 0, m, &cVar_430xMTWr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jrXdprV8, 0, m, &cVar_jrXdprV8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PabYq5z1, 0, m, &cVar_PabYq5z1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sR6ilbon, 0, m, &cVar_sR6ilbon_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HnLJNKTn, 0, m, &cVar_HnLJNKTn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qItP0mSV, 0, m, &cVar_qItP0mSV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IJmjElto, 0, m, &cVar_IJmjElto_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AkJqcOpG, 0, m, &cVar_AkJqcOpG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CdJFpjVv, 0, m, &cVar_CdJFpjVv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9fg98XsS, 0, m, &cVar_9fg98XsS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PSy4ZjN2, 0, m, &cVar_PSy4ZjN2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_07uGiGdZ, 0, m, &cVar_07uGiGdZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FcUa4G6Q, 0, m, &cVar_FcUa4G6Q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sWwq4Svx, 0, m, &cVar_sWwq4Svx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5u6iXPKr, 0, m, &cVar_5u6iXPKr_sendMessage);
  cMsg_0iJMrz5W_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_pvcGvtUB, 0, m, &cVar_pvcGvtUB_sendMessage);
  cMsg_nvpLXneX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cnLA9BwX, 0, m, &cVar_cnLA9BwX_sendMessage);
  cMsg_VFWFLOtt_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Yx6KxmDZ, 0, m, &cVar_Yx6KxmDZ_sendMessage);
  cMsg_azoBWGBW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_dLwLzVT5, 0, m, &cVar_dLwLzVT5_sendMessage);
  cMsg_UMJqvSwo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_P4nZo3zF, 0, m, &cVar_P4nZo3zF_sendMessage);
  cMsg_YBZHPlA1_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_B48xwbUx, 0, m, &cVar_B48xwbUx_sendMessage);
  cMsg_UPJcT203_sendMessage(_c, 0, m);
  cMsg_XNntXUPm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6c5thhST, 0, m, &cVar_6c5thhST_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GqAVtLzJ, 0, m, &cVar_GqAVtLzJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nbj0MVZM, 0, m, &cVar_nbj0MVZM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_V7Ne2TXF, 0, m, &cVar_V7Ne2TXF_sendMessage);
  cMsg_1nCQjIS0_sendMessage(_c, 0, m);
  cMsg_FfKWv1l6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lPXMU2Kn, 0, m, &cVar_lPXMU2Kn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_52Mv8V6j, 0, m, &cVar_52Mv8V6j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lSYmohsC, 0, m, &cVar_lSYmohsC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kkAvBEF6, 0, m, &cVar_kkAvBEF6_sendMessage);
  cMsg_qSjdPyRg_sendMessage(_c, 0, m);
  cMsg_QUSWiMRC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zCRStbNf, 0, m, &cVar_zCRStbNf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_j3AtuhWq, 0, m, &cVar_j3AtuhWq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_j3iZ6a7d, 0, m, &cVar_j3iZ6a7d_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xrkQ97I6, 0, m, &cVar_xrkQ97I6_sendMessage);
  cMsg_6q0iPPRl_sendMessage(_c, 0, m);
  cMsg_65xUxDu2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_kII3SEqi, 0, m, &cVar_kII3SEqi_sendMessage);
  cMsg_RcWYu72r_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_866y0rLw, 0, m, &cVar_866y0rLw_sendMessage);
  cMsg_zfev7x8B_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jHQZFu3d, 0, m, &cVar_jHQZFu3d_sendMessage);
  cMsg_IM71WQqH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NkoH3YKP, 0, m, &cVar_NkoH3YKP_sendMessage);
  cMsg_KnjEulG2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wZNCwqpn, 0, m, &cVar_wZNCwqpn_sendMessage);
  cMsg_5o2p56Vz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cRDVCZHT, 0, m, &cVar_cRDVCZHT_sendMessage);
  cMsg_0LsRW53K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_dH5wkyX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NldFY438, HV_BINOP_MULTIPLY, 0, m, &cBinop_NldFY438_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_UxffUNM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jAgfarwG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_y2qUoGGc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HByeeHcH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_dkLZDnyU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_mjPaqdQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ZFvdHt8P_sendMessage);
  cMsg_EQozxfq4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_1YhXy4Fk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1FhQEWpV, HV_BINOP_MULTIPLY, 0, m, &cBinop_1FhQEWpV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_WO6zUK5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_D5IDo3H2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_dqyCl9nA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2qpSPPBw, HV_BINOP_MULTIPLY, 1, m, &cBinop_2qpSPPBw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_NpEYzvfY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lXjNeo2A_sendMessage);
  cMsg_gooWCvwN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_5NI9PjUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5zuuh3xr, HV_BINOP_MULTIPLY, 0, m, &cBinop_5zuuh3xr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_1SENCUDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4zujdsKA_sendMessage(_c, 0, m);
  cMsg_LK10UBiJ_sendMessage(_c, 0, m);
  cMsg_j8pdQl8d_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_5P6npJBl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_PApR4C9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Ldz46DrF_sendMessage);
  cMsg_iN5QdppP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_XV39LpEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_38H3fZmM, 0, m, &cVar_38H3fZmM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Jp1EcPZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B0QHtppM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OAYqYTXs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_vYb67GtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FS1OvH71_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RXe7869Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qllialcb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_9uCzKMgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c24SahvR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZKKUvLKP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6wMLehcO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_lUebIi1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ye96Cf9c_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gykzpKkz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u4fhMIXV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_6XoHl93b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AZmYeAfo, HV_BINOP_MULTIPLY, 0, m, &cBinop_AZmYeAfo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_BjoU7pJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_puoBZh9D_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_s62QpUmf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_sG7PjWHb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_aMxMHbxm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_646ttw9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_EevnIgGB_sendMessage);
  cMsg_tY0Etw31_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_XFujlyht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wNnRonbV, HV_BINOP_MULTIPLY, 0, m, &cBinop_wNnRonbV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_fP9EwrOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_KcsXGbrt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_4WYNL8Pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x6wdgMTN, HV_BINOP_MULTIPLY, 1, m, &cBinop_x6wdgMTN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Jq2PXNMw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ApgILcM1_sendMessage);
  cMsg_MldnFj0S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_HTC7zDiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DXWhmc5O, HV_BINOP_MULTIPLY, 0, m, &cBinop_DXWhmc5O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_73Y7URcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nlz8AFBE_sendMessage(_c, 0, m);
  cMsg_cBXmw3uP_sendMessage(_c, 0, m);
  cMsg_bF1z5EvY_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_mqB5t0Rm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_c8UeJwBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_sYEA4GM5_sendMessage);
  cMsg_v2Mm91PR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_qCdfeWYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PxvTWe99, 0, m, &cVar_PxvTWe99_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_wk2ApgyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_niLHuVPr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_tNIhZJJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_1XxUVbSi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_zdWppVZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tSFVD0RI, 0, m, &cVar_tSFVD0RI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_aXu7RZjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_KAiYmUEm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Qu9SnytS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_6XK4Rvs9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_QbBnyW5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_DkRqtAcC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_usoIqnmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aDWscPky, 0, m, &cVar_aDWscPky_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_IhDDhcGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_TmlpHiYd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_YYH6zbQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_9Gu3yAXV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_a40So1I4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_zCuRAvq5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_sxUqu0FI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2mosq0lA, 0, m, &cVar_2mosq0lA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_M3cfvUdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_vz3TC23q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ZqQbFv3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_oX1g47Um_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_JbVasEvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_c8Oyr2tZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_JfyRyJU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_wynPy2Mq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_kXRJ6daa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_k5T7L2Rs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_vuFNOonz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_FXcTMC8P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_gnjvJDqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_FCaOEpGZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Rb2s26pO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_KHHftBP2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_YL03UqPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_u8eJKNYW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_3BKKqEk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_0HrmDyTd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_DC24oYFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_oK3agFOz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_F9D5RrrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_aIamgcMi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_QetMiaZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_5SZYGL9s_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_uRIQ6BiJ, VOf(Bf0));
    __hv_line_f(&sLine_KJr5mLqm, VOf(Bf1));
    __hv_line_f(&sLine_ZAe9gN93, VOf(Bf2));
    __hv_line_f(&sLine_qlKpkjPk, VOf(Bf3));
    __hv_line_f(&sLine_WerIpBNi, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_DXm5pEh1, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_oxg4fbbi, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_0G9uSx9n, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_zoSJCt5c, VOf(Bf1));
    __hv_line_f(&sLine_VnJSQiff, VOf(Bf0));
    __hv_line_f(&sLine_GhQ6dhbd, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_530UhoIv, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_C8hberev, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_umM8HwKO, VOf(Bf5));
    __hv_line_f(&sLine_VLwlpa9C, VOf(Bf1));
    __hv_line_f(&sLine_9ngsUJGH, VOf(Bf2));
    __hv_line_f(&sLine_x6k2zgrr, VOf(Bf4));
    __hv_line_f(&sLine_WLi1JgzX, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_T3qnFKbY, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_YmHgqUKt, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_wl6NAanL, VOf(Bf6));
    __hv_line_f(&sLine_t7hmf8nz, VOf(Bf2));
    __hv_line_f(&sLine_d8QCS00O, VOf(Bf1));
    __hv_line_f(&sLine_bZe1xwts, VOf(Bf5));
    __hv_line_f(&sLine_BuWfxXmM, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_EKH99653, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_QEWmHoIb, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_99Fa0uzR, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_JhufN57T, VOf(Bf2));
    __hv_line_f(&sLine_TmYg2HiC, VOf(Bf6));
    __hv_line_f(&sLine_Fv8yZ5fR, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_Qbbc4TAB, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_uBN4WSmC, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_WhWUZgV5, VOf(Bf8));
    __hv_line_f(&sLine_iuBgOLlq, VOf(Bf2));
    __hv_line_f(&sLine_ZEbKIH59, VOf(Bf1));
    __hv_line_f(&sLine_VMkof5Xc, VOf(Bf7));
    __hv_line_f(&sLine_KByNcpG1, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_G0CTowkO, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_FMtH8KsD, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_qQs5IpK7, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_Z4e3D788, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_ZQokkPCy, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_FL7tyaOZ, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_pCJZsCfL, VOf(Bf8));
    __hv_rpole_f(&sRPole_vqMBaN84, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_fJQLmtB2, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_gIeuRhAR, VOf(Bf10));
    __hv_rpole_f(&sRPole_oRabG9Jk, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_iNhFojnw, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_EKUyDbvr, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_QzbsP73z, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_v6T97sSV, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_Zn0depzd, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_2xmSc2OT, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_mI4Nc58Q, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_Q9x8dDLi, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_tY2fesmt, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_5gAyENIo, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_ljrZxAHJ, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_Xh7xOJFH, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_CPgPRqyb, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_sCrIV8Br, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_6ddkhNKi, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_qCXwFK6a, VIf(Bf3));
    __hv_varwrite_f(&sVarf_f692pRpR, VIf(Bf11));
    __hv_line_f(&sLine_vabtI1Tl, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_lYbCV9IN, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_bJi9cLtr, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_QcjyW8sX, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_3y8zeeFF, VOf(Bf10));
    __hv_rpole_f(&sRPole_A2IehJYW, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_TUWfJ5do, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_4Fg5KgOT, VOf(Bf5));
    __hv_rpole_f(&sRPole_gc23JTjt, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_w7ViaHRa, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_FxQqw34d, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_xUC7ZuNs, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_vx5biWG8, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_IA8eTf3p, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_8siVEKkj, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_yov4eQZX, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_XBHu9jkS, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_vyHDjAJT, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_WSjbjGf1, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_IYsELmhF, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_7cWFUCUU, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_6DV6cD51, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_78MEMfpl, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_ocz1EK2Y, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_W4T6nldM, VIf(Bf0));
    __hv_varwrite_f(&sVarf_x2MSCobF, VIf(Bf8));
    __hv_line_f(&sLine_REuKhhAj, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_OGWaKAiR, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_5MvTnuy9, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_pZsZScRd, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_3M5XRdwo, VOf(Bf5));
    __hv_rpole_f(&sRPole_TQvm6FOv, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_s7TqJwTl, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_wihsT90Y, VOf(Bf6));
    __hv_rpole_f(&sRPole_aEk43ajC, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_TMZvkCkL, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_UIa9J7JB, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_k1vrykDG, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_aOZDODzI, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_3JHSRTUj, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_NfBsefEr, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_z3pdwBDT, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_ZsNEVVov, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_CEArNN8P, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_v1Pgv8zQ, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_A2Fjr5pw, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_9XI0cy1e, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_kV4C2Slv, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_uONvVTHG, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_1sVRzSfE, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_2iS43VKo, VIf(Bf4));
    __hv_varwrite_f(&sVarf_W4PVvOX9, VIf(Bf10));
    __hv_varwrite_f(&sVarf_fmMpsCOG, VIf(Bf2));
    __hv_varwrite_f(&sVarf_HxiJJjYB, VIf(Bf9));
    __hv_varwrite_f(&sVarf_uATW42o9, VIf(Bf11));
    __hv_varread_f(&sVarf_f692pRpR, VOf(Bf11));
    __hv_varread_f(&sVarf_x2MSCobF, VOf(Bf9));
    __hv_varread_f(&sVarf_W4PVvOX9, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_fmMpsCOG, VOf(Bf2));
    __hv_varread_f(&sVarf_HxiJJjYB, VOf(Bf11));
    __hv_varread_f(&sVarf_uATW42o9, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
